#ifndef MEMORYLEAKDETECTION_H
#define MEMORYLEAKDETECTION_H

#if defined(_DEBUG) && defined(_MSC_VER)
#define _CRTDBG_MAP_ALLOC
// TODO: How can we better obtain traceback of detected leaks?
// https://docs.microsoft.com/en-us/cpp/c-runtime-library/crtdbg-map-alloc?view=msvc-170
// The _CRTDBG_MAP_ALLOC should do it already.. but it doesn't seem to cover the following:
//    #define DEBUG_NEW new(_NORMAL_BLOCK, __FILE__, __LINE__)
//    #define new DEBUG_NEW
#include <crtdbg.h>
#endif
#include <GoApi/GoApiDef.h>


namespace Go {

#if defined(_DEBUG) && defined(_MSC_VER)
#   define GoMemState _CrtMemState
#else
#   define GoMemState size_t
#endif

/*
 * Encapsulates functionality memory leak detection in GoPxLService (GOS-4862).
 */
class GoApiClass MemoryLeakDetection
{
public:
    struct GoMemoryState
    {
        GoMemState memCheckpoint;
    };

    MemoryLeakDetection();

    ~MemoryLeakDetection();

    /**
     * Creates a (initial) system leak checkpoint.
     */
    void CreateSystemLeakCheckpoint();

    /**
     * Checks, if the system has memory leaks by comparing current state to last checkpoint.
     *
     * @return  true if memory leaks exist.
     */
    bool HasSystemLeaks() const;

    /**
     * Print existing memory leaks (to console).
     */
    void PrintSystemLeaks() const;


private:
    GoMemoryState serviceMemState;
};

}; // Namespace

#endif
