/**
 * @file    GoGdpProfileUniform.cpp
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
#include <GoPxLSdk/GoGdpMsg/GoGdpProfileUniform.h>
#include <kApi/Data/kArray1.h>

namespace GoPxLSdk
{
    GoGdpProfileUniform::GoGdpProfileUniform()
        : GoGdpProfileBase(MessageType::UNIFORM_PROFILE)
    {
        ranges.Reset();
        intensities.Reset();
    }

    void GoGdpProfileUniform::Deserialize(kSerializer serializer)
    {
        GoGdpProfileBase::Deserialize(serializer);

        try
        {
            GoTest(kArray1_Construct(ranges.Ref(), kTypeOf(k16s), Width(), kAlloc_App()));
            GoTest(kSerializer_Read16sArray(serializer, kArray1_DataT(ranges, k16s), Width()));

            if (!kSerializer_ReadCompleted(serializer) && IntensityWidth() > 0)
            {
                GoTest(kArray1_Construct(intensities.Ref(), kTypeOf(k8u), IntensityWidth(), kAlloc_App()));
                GoTest(kSerializer_Read8uArray(serializer, kArray1_DataT(intensities, k8u), IntensityWidth()));
            }

        }
        catch (const Go::Exception&)
        {
            GoRethrow("Failed to deserialize Profile Uniform GDP message.");
        }
    }

    const kArray1 GoGdpProfileUniform::Ranges() const
    {
        return ranges.Get();
    }

    const kArray1 GoGdpProfileUniform::Intensities() const
    {
        return intensities.Get();
    }
}