/**
 * @file    GoTransaction.cpp
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
#include <GoPxLSdk/Def.h>
#include <GoPxLSdk/GoTransaction.h>

#include <GoPxLSdk/GoRequestError.h>
#include <GoPxLSdk/GoChannelError.h>

#include <GoApi/GoApi.h>

namespace GoPxLSdk
{

GoTransaction::GoTransaction(GoRequest request)
{
    this->request = std::move(request);
    promise = std::make_shared<std::promise<GoRequestResponse>>();
    futureResponse = promise->get_future().share();
}

void GoTransaction::CheckResponse(k64u timeout)
{
    auto const status = futureResponse.wait_for(std::chrono::microseconds(timeout));
    if (status == std::future_status::timeout)
    {
        throw GoChannelError("The request timed out.");
    }

    auto const& response = futureResponse.get();
    if (response.Status() != kOK)
    {
        throw GoRequestError(response);
    }
}

GoRequestResponse GoTransaction::GetResponse(k64u timeout)
{
    CheckResponse(timeout);
    return futureResponse.get();
}

GoRequest GoTransaction::GetRequest()
{
    return request;
}

void GoTransaction::OnResponse(const std::shared_ptr<GoRequestResponse>& response)
{
    promise->set_value(*response.get());
}

std::shared_future<GoRequestResponse>& GoTransaction::GetResponseFuture()
{
    return futureResponse;
}

}
