/**
 * @file    GoDataSet.cs
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
using System.Collections.Generic;
using GoPxLSdk.GoGdpMsg;

namespace GoPxLSdk
{
    public class GoDataSet
    {
        private readonly List<GoGdpMsg.GoGdpMsg> _content = new List<GoGdpMsg.GoGdpMsg>();

        /// <summary>Clear the vector of messages.</summary>
        public void Clear()
        {
            _content.Clear();
        }

        /// <summary>Add a msg to List.</summary>
        /// <param name="msg">The msg.</param>
        public void Add(GoGdpMsg.GoGdpMsg msg)
        {
            _content.Add(msg);
        }

        /// <summary>Get a msg.</summary>
        /// <param name="index">The index of the message.</param>
        /// <returns>a msg of content</returns>
        public GoGdpMsg.GoGdpMsg GdpMsgAt(int index)
        {
            if (index >= _content.Count)
                return null;

            return _content[index];
        }

        /// <summary>Get a msg size of vector.</summary>
        /// <returns>size of content</returns>
        public long Count => _content.Count;
    }
}