/**
 * @file    GoGdpProfilePointCloud.cs
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
using System;

namespace GoPxLSdk.GoGdpMsg
{
    public class GoGdpProfilePointCloud : GoGdpProfileBase
    {
        /// <summary>Get profile ranges.</summary>
        public GoPoint16s[] Ranges { get; internal set; }

        /// <summary>Get profile intensities.</summary>
        public byte[] Intensities { get; internal set; }

        /// <summary>Constructs GoGdpProfilePointCloud.</summary>
        public GoGdpProfilePointCloud()
            : base(MessageType.ProfilePointCloud)
        { }

        /// <summary>Deserialize profile point cloud message.</summary>
        /// <param name="serializer">The serializer to read.</param>
        internal override void Deserialize(GoBinaryReader serializer)
        {
            base.Deserialize(serializer);

            Ranges = new GoPoint16s[Width];
            for (int i = 0; i < Width; i++)
            {
                // TODO: Can this be done better?
                // Incoming data is stored as an array of 16s
                var x = serializer.ReadInt16();
                var y = serializer.ReadInt16();
                Ranges[i] = new GoPoint16s(x, y);
            }

            if (!serializer.IsReadCompleted && IntensityWidth > 0)
            {
                Intensities = serializer.ReadBytes((int)IntensityWidth);
            }
        }
    }
}