/**
 * @file    GoPoint16s.cs
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.InteropServices;
using System.Text;
using System.Threading.Tasks;

namespace GoPxLSdk
{
    [StructLayout(LayoutKind.Sequential)]
    public struct GoPoint16s
    {
        /// <summary>
        /// X-coordinate value.
        /// </summary>
        public short X { get; }

        /// <summary>
        /// Y-coordinate value.
        /// </summary>
        public short Y { get; }

        public GoPoint16s(short x, short y)
        {
            X = x;
            Y = y;
        }

        public static bool operator ==(GoPoint16s a, GoPoint16s b)
        {
            return a.Equals(b);
        }

        public static bool operator !=(GoPoint16s a, GoPoint16s b)
        {
            return (!a.Equals(b));
        }

        public override string ToString()
        {
            return $"{X}, {Y}";
        }

        public override bool Equals(object obj)
        {
            return obj is GoPoint16s f &&
                   X == f.X &&
                   Y == f.Y;
        }

        public override int GetHashCode()
        {
            int hashCode = 1861411795;
            hashCode = hashCode * -1521134295 + X.GetHashCode();
            hashCode = hashCode * -1521134295 + Y.GetHashCode();
            return hashCode;
        }
    }
}
